import Flutter
import UIKit
import QuickCaptureSDK 

public class QuickcapturePlugin: NSObject, FlutterPlugin {
    
    // Declare a property for the CameraHelper
    var cameraHelper: CameraHelper?

    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "quickcapture", binaryMessenger: registrar.messenger())
        let instance = QuickcapturePlugin()
        
        // Initialize the CameraHelper object
        instance.cameraHelper = CameraHelper()
        
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
      switch call.method {
        case "getPlatformVersion":
            result("iOS " + UIDevice.current.systemVersion)
        case "startCapture":
            if let viewController = getCurrentViewController() {
                cameraHelper?.StartCapture(sender: viewController, workingDirectory: Config.CaptureSupport.OutputPath) { (imagePaths) in
                    // On success
                    if !imagePaths.isEmpty {
                        let jsonData = self.onActivitySuccess(imagePaths: imagePaths)
                        result(jsonData)
                    } else {
                        // On failure
                        let jsonData = self.onActivityFail(methodName: "startCapture", failedDescription: "No images captured")
                        result(jsonData)
                    }
                }
            } else {
                result(FlutterError(code: "ERROR", message: "Unable to get UIViewController", details: nil))
            }
        case "buildTiffForLastCapture":
            result(nil)
        case "buildPDFForLastCapture":
            result(nil)
        case "buildPDF":
            result(nil)
        case "buildTiff":
            result(nil)
        case "compressToJPEG":
            result(nil)
        default:
            result(FlutterMethodNotImplemented)
      }
    }
      
    func getCurrentViewController() -> UIViewController? {
        guard let rootController = UIApplication.shared.keyWindow?.rootViewController else {
            return nil
        }
        var currentController: UIViewController? = rootController
        while let presentedController = currentController?.presentedViewController {
            currentController = presentedController
        }
        return currentController
    }

    class ReturnClass: Codable {
        var fileCollection: [String] = []
        var STATUS = "SUCCESS"
        var DESCRIPTION = "SUCCESS"
    }

    func onActivitySuccess(imagePaths: [String]) -> String {
        let returnClassInstance = ReturnClass()
        returnClassInstance.fileCollection = imagePaths
        
        let jsonData = try? JSONEncoder().encode(returnClassInstance)
        return String(data: jsonData!, encoding: .utf8) ?? ""
    }
    
    func onActivityFail(methodName: String, failedDescription: String?) -> String {
        var description = "Failure in Camera section : at \(methodName)"
        if let failedDesc = failedDescription, !failedDesc.isEmpty {
            description += " \(failedDesc)"
        }

        let returnClassInstance = ReturnClass()
        returnClassInstance.fileCollection = []
        returnClassInstance.STATUS = "FAILURE"
        returnClassInstance.DESCRIPTION = description
        
        let jsonData = try? JSONSerialization.data(withJSONObject: returnClassInstance, options: .prettyPrinted)
        return String(data: jsonData!, encoding: .utf8) ?? ""
    }
}
