import 'quickcapture_platform_interface.dart';

/// A class for Quickcapture SDK functionalities.
///
/// Provides a series of methods to interact with the Quickcapture platform,
/// including capturing images, building files in various formats, and image compression.
class Quickcapture {
  /// Creates a Quickcapture instance and initializes the platform.
  Quickcapture() {
    QuickcapturePlatform.instance.initialize();
  }

  /// Retrieves the platform version.
  ///
  /// Returns a `Future<String?>` that resolves to the version of the current platform.
  Future<String?> getPlatformVersion() {
    return QuickcapturePlatform.instance.getPlatformVersion();
  }

  /// Starts the capture process.
  ///
  /// Returns a `Future<String?>` upon the completion of the capture process.
  Future<String?> startCapture() {
    return QuickcapturePlatform.instance.startCapture();
  }

  /// Builds a TIFF file from the last capture.
  ///
  /// Returns a `Future<String?>` with the file path or result of the TIFF creation.
  Future<String?> buildTiffForLastCapture() {
    return QuickcapturePlatform.instance.buildTiffForLastCapture();
  }

  /// Builds a PDF file from the last capture.
  ///
  /// Returns a `Future<String?>` with the file path or result of the PDF creation.
  Future<String?> buildPDFForLastCapture() {
    return QuickcapturePlatform.instance.buildPDFForLastCapture();
  }

  /// Builds a PDF file from the available data.
  ///
  /// Returns a `Future<String?>` with the file path or result of the PDF creation.
  Future<String?> buildPDF() {
    return QuickcapturePlatform.instance.buildPDF();
  }

  /// Builds a TIFF file from the available data.
  ///
  /// Returns a `Future<String?>` with the file path or result of the TIFF creation.
  Future<String?> buildTiff() {
    return QuickcapturePlatform.instance.buildTiff();
  }

  /// Compresses the captured image to a JPEG format.
  ///
  /// Returns a `Future<String?>` with the file path or result of the compression.
  Future<String?> compressToJPEG() {
    return QuickcapturePlatform.instance.compressToJPEG();
  }

  Future<String?> _setCaptureConfig() {
    return QuickcapturePlatform.instance.setCaptureConfig();
  }
}
